@@ -8,9 +8,9 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Itself ;
-$Config::Model::Itself::VERSION = '2.008';
+$Config::Model::Itself::VERSION = '2.009';
 use Mouse ;
-use Config::Model 2.098;
+use Config::Model 2.101;
 use 5.010;
 
 use IO::File ;
@@ -278,7 +278,9 @@ sub read_all {
         # now apply some translation to read model
         # - translate legacy warp parameters
         # - expand elements name
-        my $tmp_model = Config::Model -> new( skip_include => 1, legacy => $legacy ) ;
+        my @legacy = $legacy ? ( legacy => $legacy ) : () ;
+        my $tmp_model = Config::Model -> new( skip_include => 1, @legacy ) ;
+
         # @models order is important to write configuration class back in the same
         # order as the declaration
         my @models = $tmp_model -> load ( 'Tmp' , $file ) ;
@@ -763,7 +765,7 @@ Config::Model::Itself - Model editor for Config::Model
 
 =head1 VERSION
 
-version 2.008
+version 2.009
 
 =head1 SYNOPSIS
 
