@@ -232,7 +232,7 @@
                 level      => 'normal',
                 summary     => 'configuration file mode',
                 description => 'specify the configuration file mode. C<file_mode> parameter can be used to set the '
-                    . 'mode of the written file. C<file_mode> value can be in any form suppported by L<Path::Tiny/chmod>.'
+                    . 'mode of the written file. C<file_mode> value can be in any form supported by L<Path::Tiny/chmod>.'
             },
 
             default_layer => {
@@ -299,6 +299,32 @@
                 }
             },
 
+            assign_char => {
+                type       => 'leaf',
+                value_type => 'uniline',
+                level      => 'hidden',
+                description => 'Character used to assign value in INI file. Default is C<=>. '
+                    .'See L<details|Config::Model::Backend::IniFile/"Handle key value files">',
+                upstream_default => '#',
+                warp => {
+                    follow => '- backend',
+                    rules  => [ IniFile => { level => 'normal', } ],
+                }
+            },
+
+            assign_with => {
+                type       => 'leaf',
+                value_type => 'uniline',
+                level      => 'hidden',
+                description => 'String used write assignment in INI file. Default is "C< = >". '
+                    .'See L<details|Config::Model::Backend::IniFile/"Handle key value files">',
+                upstream_default => '#',
+                warp => {
+                    follow => '- backend',
+                    rules  => [ IniFile => { level => 'normal', } ],
+                }
+            },
+
             ['join_list_value', 'join_check_list_value'] => {
                 type       => 'leaf',
                 value_type => 'uniline',
